Minnesota Supreme Court Opinions Index by Release Date

Minnesota Supreme Court Opinions & Orders
October - December 2014

#### October 15, 2014

- NO OPINIONS FILED

#### October 8, 2014

- A12-173, A13-996, State of Minnesota, Respondent, vs. Mahdi Hassan Ali, Appellant.
- A12-1944, Seagate Technology, LLC, Respondent, vs. Western Digital Corporation, et al., Appellants, Sining Mao, Appellant.
- A13-1856, In re Petition for Disciplinary Action Against A.B., a Minnesota Attorney, Panel Case No. 35121.
- A14-1548, In re Petition for Disciplinary Action against Willie Herman Davis, Jr., a Minnesota Attorney, Registration No. 298384.
- A14-1551, In re Petition for Disciplinary Action against Timothy Joseph Klima, a Minnesota Attorney, Registration No. 202885.
- ADM10-8049, ORDER PROMULGATING AMENDMENTS TO THE RULES OF CRIMINAL PROCEDURE.

#### October 1, 2014

- NO OPINIONS FILED
- ADM10-8043, ORDER PROMULGATING AMENDMENTS TO THE RULES ON LAWYERS PROFESSIONAL RESPONSIBILITY.
- List of ORDERS ON PETITIONS FOR FURTHER REVIEW FILED September 24, 2014.

MSLL Home Page | | Minnesota Appellate Court System | | Archive Homepage

Phone: (651) 296-2775; Fax: (651) 296-6740

This site is continually being updated and we welcome your input.
Please send any comments or suggestions to the Webweaver.

Last update: October 15, 2014